@@ -17,7 +17,7 @@ This package inherits I<Net::Blogger::Engine::Userland> and implements methods s
 package Net::Blogger::Engine::Manila;
 use strict;
 
-$Net::Blogger::Engine::Manila::VERSION   = 0.2.2;
+$Net::Blogger::Engine::Manila::VERSION   = '0.2.3';
 @Net::Blogger::Engine::Manila::ISA       = qw ( Exporter Net::Blogger::Engine::Userland );
 @Net::Blogger::Engine::Manila::EXPORT    = qw ();
 @Net::Blogger::Engine::Manila::EXPORT_OK = qw ();
@@ -61,11 +61,11 @@ sub getUsersBlogs {
 
 =head1 VERSION
 
-0.2.2
+0.2.3
 
 =head1 DATE
 
-April 15, 2002
+May 04, 2002
 
 =head1 AUTHOR
 
@@ -73,6 +73,16 @@ Aaron Straup Cope
 
 =head1 CHANGES
 
+=head2 0.2.3
+
+=over
+
+=item *
+
+Added quotes to I<$VERSION>
+
+=back
+
 =head2 0.2.2
 
 =over
